"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstractCollection_1 = require("./abstractCollection");
class HolidaySchemes extends abstractCollection_1.default {
    /**
     * Retrieve all holiday schemes
     */
    get() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/holiday-schemes');
        });
    }
    /**
     * Create a Holiday scheme
     */
    post(holidayScheme) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/holiday-schemes', {
                body: holidayScheme,
                method: 'POST',
            });
        });
    }
    /**
     * Retrieve an existing holiday scheme
     */
    getHolidayScheme(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}`);
        });
    }
    /**
     * Update a holiday scheme
     */
    putHolidayScheme(id, holidayScheme) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}`, {
                body: holidayScheme,
                method: 'PUT',
            });
        });
    }
    /**
     * Delete a holiday scheme
     */
    deleteHolidayScheme(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}`, {
                method: 'DELETE',
            });
        });
    }
    /**
     * Set the default holiday scheme
     */
    putHolidaySchemeDefault(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/default`, {
                method: 'PUT',
            });
        });
    }
    /**
     * Retrieve holidays for an existing holiday scheme
     */
    getHolidaySchemeHolidays(id, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/holidays`, {
                query: options,
            });
        });
    }
    /**
     * Create a Holiday
     */
    postHolidaySchemeHoliday(id, holiday) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/holidays`, {
                body: holiday,
                method: 'POST',
            });
        });
    }
    /**
     * Retrieve an existing holiday
     */
    getHolidaySchemeHoliday(id, holidayId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/holidays/${holidayId}`);
        });
    }
    /**
     * Update a holiday
     */
    putHolidaySchemeHoliday(id, holidayId, holiday) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/holidays/${holidayId}`, {
                body: holiday,
                method: 'PUT',
            });
        });
    }
    /**
     * Delete a holiday
     */
    deleteHolidaySchemeHoliday(id, holidayId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/holidays/${holidayId}`, {
                method: 'DELETE',
            });
        });
    }
    /**
     * Retrieve all floating holidays for an existing holiday scheme.
     */
    getHolidaySchemeFloatingHolidays(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/holidays/floating`);
        });
    }
    /**
     * Get members in a holiday scheme
     *
     * Note: Tempo.io documentation seems to be broken.
     */
    getHolidaySchemeMembers(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/members`);
        });
    }
    /**
     * Assign a holiday scheme to members
     */
    postHolidaySchemeMembers(id, accountIds) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/${id}/members`, {
                body: { accountIds },
                method: 'POST',
            });
        });
    }
    /**
     * Get user scheme
     */
    getForUser(accountId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/holiday-schemes/users/${accountId}`);
        });
    }
}
exports.default = HolidaySchemes;
//# sourceMappingURL=holidaySchemes.js.map