"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstractCollection_1 = require("./abstractCollection");
class Roles extends abstractCollection_1.default {
    /**
     * Retrieve all roles
     */
    get() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/roles');
        });
    }
    /**
     * Creates a new role
     */
    post(role) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/roles', {
                body: role,
                method: 'POST',
            });
        });
    }
    /**
     * Retrieve the default role
     */
    getDefault() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/roles/default');
        });
    }
    /**
     * Retrieve an existing role for the given id
     */
    getRole(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/roles/${id}`);
        });
    }
    /**
     * Update an existing role for the given id
     */
    putRole(id, role) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/roles/${id}`, {
                body: role,
                method: 'PUT',
            });
        });
    }
    /**
     * Delete an existing role
     */
    deleteRole(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.createAndSendRequest(`/roles/${id}`, {
                method: 'DELETE',
            });
        });
    }
}
exports.default = Roles;
//# sourceMappingURL=roles.js.map