import { WorkloadScheme } from '../requestTypes';
import { WorkloadSchemeResponse, ResultSetResponse, UserResponse } from '../responseTypes';
import Collection from './abstractCollection';
export default class WorkloadSchemes extends Collection {
    /**
     * Retrieve all workload schemes
     */
    get(): Promise<ResultSetResponse<WorkloadSchemeResponse>>;
    /**
     * Create a workload scheme
     */
    post(workloadScheme: WorkloadScheme): Promise<WorkloadSchemeResponse>;
    /**
     * Retrieve an existing workload scheme for the given id
     */
    getWorkloadScheme(id: string): Promise<WorkloadSchemeResponse>;
    /**
     * Update a workload scheme for the given id
     */
    putWorkloadScheme(id: string, workloadScheme: WorkloadScheme): Promise<WorkloadSchemeResponse>;
    /**
     * Delete a workload scheme for the given id
     */
    deleteWorkloadScheme(id: string): Promise<void>;
    /**
     * Set the default workload scheme
     */
    putWorkloadSchemeDefault(id: string): Promise<WorkloadSchemeResponse>;
    /**
     * Get members in a workload scheme
     */
    getWorkloadSchemeMembers(id: string): Promise<ResultSetResponse<UserResponse>>;
    /**
     * Set user workload scheme membership
     */
    postWorkloadSchemeMembers(id: string, accountIds: string[]): Promise<void>;
    /**
     * Get user scheme
     */
    getForUser(accountId: string): Promise<WorkloadSchemeResponse>;
}
