"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstractCollection_1 = require("./abstractCollection");
class Worklogs extends abstractCollection_1.default {
    get(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/worklogs', {
                query: options,
            });
        });
    }
    post(worklog) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/worklogs', {
                body: worklog,
                method: 'POST',
            });
        });
    }
    getWorklog(worklogId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/${worklogId}`);
        });
    }
    putWorklog(worklogId, worklog) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/${worklogId}`, {
                body: worklog,
                method: 'PUT',
            });
        });
    }
    deleteWorklog(worklogId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.createAndSendRequest(`/worklogs/${worklogId}`, {
                method: 'DELETE',
            });
        });
    }
    getWorklogWorkAttributeValues(worklogId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/${worklogId}/work-attribute-values`);
        });
    }
    getWorklogWorkAttributeValuesByKey(worklogId, key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/${worklogId}/work-attribute-values/${key}`);
        });
    }
    getForJiraWorklog(jiraWorklogId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/jira/${jiraWorklogId}`);
        });
    }
    getForJiraFilter(jiraFilterId, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/jira/filter/${jiraFilterId}`, {
                query: options,
            });
        });
    }
    getForAccount(accountKey, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/account/${accountKey}`, {
                query: options,
            });
        });
    }
    getForProject(projectKey, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/project/${projectKey}`, {
                query: options,
            });
        });
    }
    getForTeam(teamId, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/team/${teamId}`, {
                query: options,
            });
        });
    }
    getForUser(accountId, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/user/${accountId}`, {
                query: options,
            });
        });
    }
    getForIssue(key, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/worklogs/issue/${key}`, {
                query: options,
            });
        });
    }
    /**
     * Bulk create work attribute values for worklogs
     */
    postWorkAttributeValues(worklogAttributeValuesList) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/worklogs/work-attribute-values', {
                body: worklogAttributeValuesList,
                method: 'POST',
            });
        });
    }
}
exports.default = Worklogs;
//# sourceMappingURL=worklogs.js.map